# Funkce

Reálná funkce jedné reálné proměnné je zobrazení $f$ s definičním oborem $D \subset \mathbb{R}$ a oborem hodnot $H \subset \mathbb{R}$.
- Každému argumentu $x \in D$ je přiřazena právě jedna funkční hodnota $y = f(x) \in \mathbb{R}$.

Každá funkce je definována zároveň
	- **funkčním předpisem** ($f(x) = x^2$),
	- **definičním oborem** ($D_{f} = \mathbb{R}$).

Mějme dvě funkce $f$ a $g$.
1) Funkce $f$ a $g$ jsou si **rovny**, pokud $D(f) = D(g)$ a pro každé $x \in D(f)$ platí $f(x) = g(x)$.
2) Funkce $f$ je **zúžením (restrikcí)** funkce $g$, pokud $D(f) \subset D(g)$ a pro každé $x \in D(f)$ platí $f(x) = g(x)$.

Mějme dány dvě funkce $f, g$ se stejným definičním oborem $D$.

| typ               | zápis                      | definice                                       |
| ----------------- | -------------------------- | ---------------------------------------------- |
| **součet funkcí** | $f+g$                      | $y = f(x) + g(x), x \in D$                     |
| **rozdíl funkcí** | $f-g$                      | $y = f(x) - g(x), x \in D$                     |
| **součin funkcí** | $f \cdot g$                | $y = f(x) \cdot g(x), x \in D$                 |
| **podíl funkcí**  | $\displaystyle\frac{f}{g}$ | $\displaystyle y = \frac{f(x)}{g(x)}, x \in D$ |

### Definiční obor $D_{f}$

- všechny hodnoty, kterých může funkce nabývat **na ose X**
- je možné jím **funkci omezit** (např.: $D_{f} = (0, 1)$)
- zjišťuje se **hledáním** definičních oborů **jiných funkcí nebo operací** (např.: $\sqrt{ -2 }$ nebo $\frac{1}{0}$)

### Obor hodnot $H_{f}$

- všechny hodnoty, kterých může funkce nabývat **na ose Y**

### Monotonie funkce

| značka | typ             | podmínka                                                                  |
| ------ | --------------- | ------------------------------------------------------------------------- |
| **R**  | rostoucí        | $\displaystyle \forall x,y \in D_{f} : x < y \implies f(x) \leq f(y)$ |
| **K**  | klesající       | $\displaystyle \forall x,y \in D_{f} : x < y \implies f(x) \geq f(y)$ |
| **OR** | ostře rostoucí  | $\displaystyle \forall x,y \in D_{f} : x < y \implies f(x) \lt f(y)$  |
| **OK** | ostře klesající | $\displaystyle \forall x,y \in D_{f} : x < y \implies f(x) \gt f(y)$  |
| **M**  | monotónní       | je klesající nebo rostoucí                                                |
| **OM** | ostře monotónní | je ostře klesající nebo ostře rostoucí                                    |

Je-li funkce $f$ **ostře monotónní**, potom je **prostá**.

### Symetrie

- **Sudá**
	- symetrická podle osy Y
	- $\forall x\in D_{f} :$
		- $-x \in D_{f}$
		- $f(-x) = f(x)$
- **Lichá**
	- symetrická podle bodu $[0, 0]$
	- $\forall x\in D_{f} :$
		- $-x \in D_{f}$
		- $f(-x) = -f(x)$

### Omezenost

| značka | typ           | podmínka                                                           |
| ------ | ------------- | ------------------------------------------------------------------ |
| **OZ** | omezená zdola | $\exists d \in \mathbb{R} : \forall x \in D_{f} \ \ \ f(x) \geq d$ |
| **OS** | omezená shora | $\exists h \in \mathbb{R} : \forall x \in D_{f} \ \ \ f(x) \leq h$ |
| **O**  | omezená       | pokud je **OZ** i **OS**                                           |

### Prostá funkce

Funkce $f$, v jejíž oboru hodnot $H(f)$ se žádná hodnota neopakuje.
- $\forall x_{1}, x_{2} \in D_{f} : x_{1} \neq x_{2} \implies f(x_{1}) \neq f(x_{2})$

### Periodicita

Funkce je periodická, jestliže existuje $T > 0$ takové, že platí:
- $\forall x \in D_{f} :$
	- $(x \pm T) \in D_{f}$
	- $f(x \pm T) = f(x)$

### Konvexní / konkávní

- konvexní: šťastný smajlík
- konkávní: smutný smajlík

### Rovnice o jedné neznámé

Mějme dánu funkci $f$ a reálné číslo $b$.
- Úloha najít $x_{0} \in D(f)$ takové, že $f(x_{0}) = b$, se nazývá **rovnice o jedné neznámé** a zapisuje se $f(x) = b$.
- Číslo $x_{0}$ je **řesení** (či **kořen**) rovnice.

Mějme dánu rovnici $f(x) = b$.

| podmínka                     | řešení                        |
| ---------------------------- | ----------------------------- |
| $b \in H(f)$                 | $\geq 1 \quad$ alespoň jedno řešení |
| $f$ je prostá                | $\leq 1 \quad$ nejvýše jedno řešení |
| $b \in H(f)$ a $f$ je prostá | $= 1 \quad$ právě jedno řešení      |

### Inverzní funkce

Funkce, která přiřazuje prvky „opačně“ než původní funkce.
- existuje pouze u funkcí **prostých**
- $f(x)=y \leftrightarrow f^{-1}(y)=x$

Je-li funkce **ostře monotónní**, potom existuje inverzní funkce.

Vypočítáme tak, že funkci přepíšeme do rovnice ($y = 2x$) a osamostatníme x ($\frac{y}{2} = x$).

| funkce               | podmínka                                              | inverzní funkce      |
| -------------------- | ----------------------------------------------------- | -------------------- |
| $x^n$                |                                                       | $\sqrt[n]{x}$        |
| $\sqrt[n]{x}$        |                                                       | $x^n$                |
| $e^x$                |                                                       | $\ln(x)$             |
| $\ln(x)$             |                                                       | $e^x$                |
| $a^x$                | $a > 0$                                               | $\log_{a}(x)$        |
| $\log_{a}(x)$        | $a > 0$                                               | $a^x$                |
| $\sin(x)$            | $x \in \langle -\frac{\pi}{2}, \frac{\pi}{2} \rangle$ | $\arcsin(x)$         |
| $\arcsin(x)$         | $x \in \langle -1, 1 \rangle$                         | $\sin(x)$            |
| $\cos(x)$            | $x \in \langle -\frac{\pi}{2}, \frac{\pi}{2} \rangle$ | $\arccos(x)$         |
| $\arccos(x)$         | $x \in \langle -1, 1 \rangle$                         | $\cos(x)$            |
| $\tan(x)$            | $x \in \left( -\frac{\pi}{2}, \frac{\pi}{2} \right)$  | $\arctan(x)$         |
| $\arctan(x)$         |                                                       | $\tan(x)$            |
| $\text{cotan}(x)$    | $x \in (0, \pi)$                                      | $\text{arccotan}(x)$ |
| $\text{arccotan}(x)$ |                                                       | $\text{cotan}(x)$    |

### Skládání funkcí

Dvě funkce, které se skládají do sebe.
- zapisuje se $f \circ g$
- druhá se vkládá do první: $f(g(x))$
- pro funkce musí platit $H(g) \subset D(f)$
- výsledný definiční obor je $x \in D(g)$

### Průběh funkce

Hrubé schéma

1. $D_f$ + limity v krajních bodech
2. spojitost na $D_f$, body nespojitosti
3. symetrie (sudá / lichá)
4. periodicita
5. znaménko $f(x)$ + průsečíky s osou $x$
6. znaménko $f'(x)$ + monotonie + extrémy
7. znaménko $f''(x)$ + konvexita/konkávita + inflexe
8. asymptoty v krajních bodech $D_f$
9. $H_f$