# Neurčité integrály

## Primitivní funkce

Mějme funkce $f$ a $F$, které jsou definované alespoň na intervalu $(a;b)$, kde $-\infty \leq a < b \leq +\infty$. Řekněme, že funkce $F$ je **primitivní funkcí** k funkci $f$ na intervalu $(a;b)$, pokud

$$\forall \space x \in (a;b) : F'(x) = f(x).$$

Nechť $F$ je primitivní funkce k funkci $f$ na intervalu $(a; b)$. Potom platí:  
1) $F$ je spojitá na $(a; b)$.  
2) Každá funkce ve tvaru $y = F (x) + C$, kde $C \in \mathbb{R}$, je primitivní funkcí k funkci $f$ na $(a; b)$.  
3) Každá primitivní funkce k funkci $f$ na $(a; b)$ je ve tvaru $y = F (x) + C$, kde $C \in R$.

## Neurčitý integrál

Mějme funkce $f$ a $F$, které jsou definované alespoň na intervalu $(a;b)$, kde $-\infty \leq a < b \leq +\infty$.  Existuje-li primitivní funkce $F$ k funkci $f$ na $(a;b)$, potom říkáme, že funkce $f$ je **integrovatelná** na intervalu $(a;b)$ a **neurčitým integrálem** funkce $f$ na intervalu $(a;b)$ rozumíme množinu __všech__ primitivních funkcí k funkci $f$ na $(a;b)$:
$$
\int f(x) \, dx = \{F(x) + C : C \in \mathbb{R}\} \quad (\text{píšeme jen } F(x) + C; C \in \mathbb{R})
$$

Je-li funkce $f$ **spojitá** na intervalu $(a; b)$, potom je na tomto intervalu **integrovatelná**.

### Linearita neurčitého integrálu

Mějme funkce $f, g$, které jsou integrovatelné na intervalu $(a;b)$. Potom na intervalu $(a;b)$ platí
1) $\displaystyle\int (f(x)+g(x)) \, dx = \int f(x) \, dx + \int g(x) \, dx$,
2) $\displaystyle\int cf(x) \, dx = c \int f(x) \, dx, \quad c\in \mathbb{R} \setminus \{ 0 \}$.

### Per-partes

Mějme funkce $u, v$, které mají konečné derivace ve všech bodech intervalu $(a;b)$. Potom na intervalu $(a;b)$ platí
- $\displaystyle\int u(x)v'(x) \, dx = u(x)v(x) - \int u'(x)v(x) \, dx$,

pokud integrál na pravé straně existuje.

#### Cyklické integrály

Některé integrály se mohou cyklit (typicky ty obsahující goniometrické funkce nebo $e^x$).

**Postup:**
- Postupujeme podle per-partes (a zachováváme pořadí, ve kterém jsme dosazovali).
- Po několika krocích se dostaneme do stavu, kdy se ve výsledku opět objeví stejný integrál jako v zadání.
- Vytvoříme rovnici **původní integrál = aktuální postup** a vyjádříme původní integrál (většinou přičtením a vydělením dvěma).

### 1. substituční metoda

Mějme funkci $f$, která je spojitá na intervalu $(c;d)$. Dále mějme funkci $g: y = g(x)$, která má konečnou derivaci ve všech bodech intervalu $(a;b)$ a $H(g) \subset (c;d)$. Potom na intervalu $(a;b)$ platí
$$
\displaystyle\int f(g(x))g'(x) \, dx = \int f(y) \, dy  
$$

dosadíme-li napravo $x = g(y)$.

### 2. substituční metoda

Mějme funkci $f$, která je spojitá na intervalu $(c;d)$. Dále mějme funkci $g: y = g(x)$ s definičním oborem $D(g) = (a;b)$ a oborem hodnot $H(g) = (c;d)$, která má konečnou a nenulovou derivaci ve všech bodech $x \in D(g)$. Potom na intervalu $(c;d)$ platí
$$
\displaystyle\int f(y) \, dy = \int f(g(x))g'(x) \, dx 
$$

dosadíme-li napravo $x = g^{-1}(y)$.

## Integrační vzorce

| funkce                                   | integrace                             |
| ---------------------------------------- | ------------------------------------- |
| $0$                                      | $C$                                   |
| $1$                                      | $x + C$                               |
| $x^n$                                    | $\displaystyle\frac{x^{n+1}}{n+1} + C$    |
| $\displaystyle\frac{dx}{x}$                           | $\ln \vert x\vert + C$                |
| $e^x$                                    | $e^x + C$                             |
| $a^x$                                    | $\displaystyle\frac{a^x}{\ln(a)} + C$ |
| $\sin(x)$                                | $-\cos(x) + C$                        |
| $\cos(x)$                                | $\sin(x) + C$                         |
| $\displaystyle\frac{dx}{\cos^2x}$        | $\tan(x) + C$                         |
| $\displaystyle\frac{dx}{\sin^2x}$        | $-\cot(x) + C$                        |
| $\displaystyle\frac{dx}{1+x^2}$          | $\arctan(x) + C$                      |
| $\displaystyle\frac{dx}{\sqrt{ 1-x^2 }}$ | $\arcsin(x) + C$                      |

### Vzorečky na typ s goniometrickými funkcemi (sin, cos)

- $\displaystyle\int \sin(x) \cdot \sin(y) \, dx = \frac{1}{2} \int(\cos(y-x)-\cos(x+y)) \, dx$
- $\displaystyle\int \sin(x) \cdot \cos(y) \, dx = \frac{1}{2} \int (\sin(x+y)-\sin(y-x)) \, dx$
- $\displaystyle\int \cos(x) \cdot \cos(y) \, dx = \frac{1}{2} \int (\cos(x+y)+\cos(y-x)) \, dx$